#ifndef NT2_INCLUDE_CONSTANTS_QUARTER_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_QUARTER_HPP_INCLUDED

#include <nt2/constant/include/constants/quarter.hpp>

#endif
